# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-06-25 04:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0002_page_version'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='page_version',
            options={'ordering': ['-saved']},
        ),
        migrations.AlterField(
            model_name='page',
            name='lastmod',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name='page',
            name='sitemap',
            field=models.BooleanField(default=True, verbose_name='Share a link to this page with search engines'),
        ),
        migrations.AlterField(
            model_name='page',
            name='title',
            field=models.CharField(max_length=100, verbose_name='Menu Title'),
        ),
        migrations.AlterField(
            model_name='page_version',
            name='saved',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
