# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-08 03:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0004_auto_20170807_2207'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='content',
            field=models.TextField(blank=True, null=True),
        ),
    ]
