# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-08 03:07
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0003_auto_20170624_2338'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='site',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='churchnest_site.Churchnest_Site'),
        ),
        migrations.DeleteModel(
            name='Site',
        ),
    ]
