{% extends 'desktop.html' %}

{% block content %}

Are you sure you want to delete:
<h1>{{ object}}</h1>

{% if error_message %}<p><strong>{{ error_message }}</strong></p>{% endif %}

<form action="" method="post">
{% csrf_token %}
{{form}}
<input type="submit" value="Delete" />
</form>

{% endblock %}