{% extends 'desktop.html' %}

{% block content %}

<form method="post" class="form-inline">
{% csrf_token %}
  <fieldset>
    <legend>Add Page Editor</legend>
    <input name="username" type="text" placeholder="search by username">
    <input name="first_name" type="text" placeholder="search by firstname">
    <input name="last_name" type="text" placeholder="search by lastname">
    <button type="submit" class="btn">Search</button>
  </fieldset>
</form>

<ol>
	{% for editor in found_editors %}
		<li>
			{{editor.get_full_name}} ({{editor.username}})
			<form method="post" class="form-inline" style="display:inline;">
				{% csrf_token %}
				<input type="hidden" name="add_editor" value="{{editor.pk}}">
			    <button type="submit" class="btn">Add</button>
			</form>
		</li>
	{% endfor %}
</ol>
{% endblock %}