{% for entry in feed %}
    {% if feed|length > 1 %}
        <div class="rss_item well">
    {% endif %}
<a href="{{ entry.link }}" target="rss">
    {{ entry.title }}
</a>
{% if not headers_only %}
    <div class="rss_description">{% if max_words %}{{ entry.description|safe|truncatewords_html:max_words }}{% else %}
        {{ entry.description|safe }}{% endif %}</div>
{% endif %}
{% if feed|length > 1 %}
    </div>
{% endif %}
{% endfor %}